
############################################
###               S E T U P              ###
############################################

rm(list=ls(all=T))
fileDir <- 'C:/Users/Maarten/Dropbox/First-Year Research Project/ACT-R/output_tests/all'
setwd(fileDir)

library("stringr")
library("ggplot2")
library("diagram")
library("qgraph")
library("psych")
library("plyr")
library("tikzDevice")
options("tikzDocumentDeclaration" = "\\documentclass[12pt]{article}\n") # Default is 10pt.
library("scales")



### Read all Rdata files from the working directory and combine into a single dataframe
files <- list.files(pattern="tracedat.Rdata")

contents <- lapply(files, function(x) {
    load(file = x)
    get("distractionContent")
})

dat <- do.call("rbind", contents)

### Add model name to the data frame
dat$model <- rep(files, sapply(contents, nrow))
dat$type <- gsub("_p.*", "", dat$model)


### Remove any ITEMATTEND chunks, but keep copy of full data
dat_full <- dat
dat <- dat[!grepl("ITEMATTEND", dat$memory),]

### Specify valence of attend chunk in full data
dat_full[grepl("ITEMATTENDPOS", dat_full$memory),]$valence <- "attend (+)"
dat_full[grepl("ITEMATTENDNEG", dat_full$memory),]$valence <- "attend (-)"


############################################
###           P L O T T I N G            ###
############################################

## Number of occurences of each valence

plot.valence.hist <- function(dat) {
    ggplot(dat, aes(x=valence)) +
        geom_bar(color="black") +
        xlab("Valence") +
        scale_fill_manual(values=c("#CCCCCC","#FFFFFF")) +
        theme_bw() +
        theme(axis.title.x=element_text(size=15),axis.text.x = element_text(size=10), axis.text.y = element_text(size=10),axis.title.y=element_text(size=15)) +
        guides(fill=FALSE)
}

# YELLOW AND BLUE
scale_fill_custom <- function(...){
    discrete_scale("fill","Custom",manual_pal(values = c("#fdb462","#386cb0")), ...) # Colours of plot can be changed here.
}

plot.comparison.tex <- function(plotDat, xvar, yvar, fillvar, xlab = "Chunk type", ylab = "Proportion of retrievals", labels, filename) {
    tikz(file = paste0(filename, ".tex"), width = 2.9, height = 2.25)
    
    dodge <- position_dodge(width=0.9)
    
    plot <- ggplot(plotDat, aes(x = as.factor(xvar), y = yvar, group = as.factor(fillvar), fill = as.factor(fillvar))) +  
        geom_bar(stat = "identity", position=dodge) +
        geom_errorbar(aes(ymin=mean-sd, ymax=mean+sd), width=0.2, position=dodge) +
        scale_y_continuous() +
        labs(x = xlab,
             y = ylab) +
        theme_classic() +
        theme(
            axis.text.x = element_text(size = rel(0.9)),
            axis.text.y = element_text(size = rel(0.9)),
            axis.title = element_text(size = rel(0.9)),
            legend.title = element_text(size = rel(0.9)),
            legend.text = element_text(size = rel(0.9)),
            legend.key.size = unit(0.4, "cm"),
            legend.position = "bottom",
            legend.direction = "horizontal",
            legend.justification = "center",
            legend.margin = unit(0.1, "cm"),
            legend.background = element_rect(colour = "black", size = 0.5)
        ) +
        scale_fill_custom("Model", labels = labels,  guide = guide_legend(title.position = "left"))
    
    print(plot)
    dev.off()
    print(plot)
}

# RED AND GREEN
scale_fill_custom <- function(...){
    discrete_scale("fill","Custom",manual_pal(values = c("#ef3b2c", "#7fc97f")), ...) # Colours of plot can be changed here.
}



## Transition probabilities
plot.trans.probs <- function(dat, graph.title, grey=TRUE) {
    
    valences <- unique(dat$valence)
    
    p <- matrix(nrow = length(valences), ncol = length(valences), 0)
    row.names(p) <- valences
    colnames(p) <- valences
    
    for (i in 1:(nrow(dat) - 1)) {
        # Go over items in sets of two
        # If they're in the same thought train, count the transition
        if (dat$trainID[i] == dat$trainID[i+1]) {
            p[dat$valence[i], dat$valence[i+1]] <- p[dat$valence[i], dat$valence[i+1]] + 1
        }
    }
    
    # Convert counts to probability
    p <- p / rowSums(p)
    
    # Transpose transition matrix
    p <- t(p)
    
    # Shorten names to first four chars to fit plot
    row.names(p) <- substr(row.names(p), 1, 4)
    colnames(p) <- substr(colnames(p), 1, 4)
    
    # Sort matrix rows and columns alphabetically
    p <- p[order(c((row.names(p)))), order(c((colnames(p))))]
    probs <- p
    # Plot transitions in a style similar to Wigman et al. (2015)
    
    qgraph(
        t(p), # transition probabilities, rounded to two decimal places
        layout = "circle",
        vsize = 15,
        esize = 10,
        mar = c(8,7,8,7), # Margin size (bottom, left, top, right)
        labels = c("cheerful", "content", "down", "insecure", "suspicious"),
        # labels = c("attend (-)", "attend (+)", "cheerful", "content", "down", "insecure", "suspicious"),
        label.norm = "suspicious",
        edge.labels = TRUE, # Show numbers on arrows
        edge.label.cex = 1, # Size of edge labels
        border.width = 2, # Width of the borders of the nodes
        colFactor = 0.15, # controls degree of transparancy
        asize = 5, # Size of arrow heads
        maximum = 0.3, # Maximum transition probability, used for scaling
        gray = grey, # Plot in greyscale instead of using colour
        filetype = "pdf", # set to "pdf" or "tex" for standalone files
        filename = paste0(gsub(" ", "_", graph.title), "_num")
    )
    
    return(probs)
    
}

# Look at the distribution of retrievals for both models
control <- dat[dat$type == "control",]
depressed <- dat[dat$type == "depressed",]

## How many retrievals of each valence?
plot.valence.hist(control)
plot.valence.hist(depressed)

compdat <- ddply(dat,.(model,valence),summarise,freq=length(valence), .drop=FALSE)
totals <- rep(ddply(compdat,.(model),summarise,total=sum(freq))$total, each = 5)
compdat$fraction <- compdat$freq/totals
compdat$type <- gsub("_p.*", "", compdat$model)

plotDat <- ddply(compdat,.(type,valence),summarise,mean=mean(fraction), sd=sd(fraction))

plot.comparison.tex(plotDat = plotDat, xvar = plotDat$valence, yvar = plotDat$mean, fillvar = plotDat$type, labels = c("Control", "Depressed"), filename = "models_comparison_hist")

## Look at the transition probabilities within the thought pump for both models
tp.control <- plot.trans.probs(control, "control")
tp.control.pos <- tp.control[1:2,1:2]
diag(tp.control.pos) <- NA
mean(tp.control.pos, na.rm = TRUE)

tp.control.neg <- tp.control[3:5,3:5]
diag(tp.control.neg) <- NA
mean(tp.control.neg, na.rm = TRUE)

tp.control.between <- tp.control
tp.control.between[1:2,1:2] <- NA
tp.control.between[3:5,3:5] <- NA
mean(tp.control.between, na.rm = T)

tp.dep <- plot.trans.probs(depressed, "depressed")
tp.dep.pos <- tp.dep[1:2,1:2]
diag(tp.dep.pos) <- NA
mean(tp.dep.pos, na.rm = TRUE)

tp.dep.neg <- tp.dep[3:5,3:5]
diag(tp.dep.neg) <- NA
mean(tp.dep.neg, na.rm = TRUE)

tp.dep.between <- tp.dep
tp.dep.between[1:2,1:2] <- NA
tp.dep.between[3:5,3:5] <- NA
mean(tp.dep.between, na.rm = T)


## Transition probabilities with item-attend
#plot.trans.probs(dat_full[dat_full$type == "control",], "control_full")
#plot.trans.probs(dat_full[dat_full$type == "depressed",], "depressed_full")


### Mean activation over all chunks in memory

# Control
affectMeansControl <- data.frame(rbind(cbind(control$pamean, "positive"), cbind(control$namean, "negative")))
names(affectMeansControl) <- c("Activation", "Valence")
affectMeansControl$Activation <- round(as.numeric(as.character(affectMeansControl$Activation)),1)

plotdat <- ddply(affectMeansControl, c("Activation", "Valence"), summarise, freq=length(Activation), .drop = FALSE)
dat.control.affectmean <- plotdat

tikz(file = paste0("affect_means_control", ".tex"), width = 2.9, height = 2.25)

plot <- ggplot(plotdat, aes(x=Activation, y = freq, fill = Valence)) +
        geom_bar(stat="identity", position="dodge") +
        xlab("Mean activation") +
        ylab("Frequency") +
        theme_classic() +
        theme(
            axis.text.x = element_text(size = rel(0.9)),
            axis.text.y = element_text(size = rel(0.9)),
            axis.title = element_text(size = rel(0.9)),
            legend.title = element_text(size = rel(0.9)),
            legend.text = element_text(size = rel(0.9)),
            legend.key.size = unit(0.4, "cm"),
            legend.position = "bottom",
            legend.direction = "horizontal",
            legend.justification = "center",
            legend.margin = unit(0.1, "cm"),
            legend.background = element_rect(colour = "black", size = 0.5)
        ) +
        scale_fill_custom("Valence", labels = c("negative", "positive"),  guide = guide_legend(title.position = "left")) +
        geom_vline(xintercept=mean(affectMeansControl[affectMeansControl$Valence=="positive",]$Activation), color="darkgreen", linetype = "longdash") +
        geom_vline(xintercept=mean(affectMeansControl[affectMeansControl$Valence=="negative",]$Activation), color="darkred", linetype = "longdash")

print(plot)
dev.off()
print(plot)

mean(affectMeansControl[affectMeansControl$Valence=="positive",]$Activation)
mean(affectMeansControl[affectMeansControl$Valence=="negative",]$Activation)

observations <- sum(dat.control.affectmean$freq)/2
dat.control.affectmean$fraction <- dat.control.affectmean$freq / observations
dat.control.affectmean$type <- "control"

# Depressed
affectMeansDepressed <- data.frame(rbind(cbind(depressed$pamean, "positive"), cbind(depressed$namean, "negative")))
names(affectMeansDepressed) <- c("Activation", "Valence")
affectMeansDepressed$Activation <- round(as.numeric(as.character(affectMeansDepressed$Activation)),1)

plotdat <- ddply(affectMeansDepressed, c("Activation", "Valence"), summarise, freq=length(Activation), .drop = FALSE)
dat.depressed.affectmean <- plotdat

tikz(file = paste0("affect_means_depressed", ".tex"), width = 2.9, height = 2.25)

plot <- ggplot(plotdat, aes(x=Activation, y = freq, fill = Valence)) +
    geom_bar(stat="identity", position="dodge") +
    xlab("Mean activation") +
    ylab("Frequency") +
    theme_classic() +
    theme(
        axis.text.x = element_text(size = rel(0.9)),
        axis.text.y = element_text(size = rel(0.9)),
        axis.title = element_text(size = rel(0.9)),
        legend.title = element_text(size = rel(0.9)),
        legend.text = element_text(size = rel(0.9)),
        legend.key.size = unit(0.4, "cm"),
        legend.position = "bottom",
        legend.direction = "horizontal",
        legend.justification = "center",
        legend.margin = unit(0.1, "cm"),
        legend.background = element_rect(colour = "black", size = 0.5)
    ) +
    scale_fill_custom("Valence", labels = c("negative", "positive"),  guide = guide_legend(title.position = "left")) +
    geom_vline(xintercept=mean(affectMeansDepressed[affectMeansDepressed$Valence=="positive",]$Activation), color="darkgreen", linetype = "longdash") +
    geom_vline(xintercept=mean(affectMeansDepressed[affectMeansDepressed$Valence=="negative",]$Activation), color="darkred", linetype = "longdash")

print(plot)
dev.off()
print(plot)

mean(affectMeansDepressed[affectMeansDepressed$Valence=="positive",]$Activation)
mean(affectMeansDepressed[affectMeansDepressed$Valence=="negative",]$Activation)

observations <- sum(dat.depressed.affectmean$freq)/2
dat.depressed.affectmean$fraction <- dat.depressed.affectmean$freq / observations
dat.depressed.affectmean$type <- "depressed"

####
####
####
####

### Summed activation over all chunks in memory



# Control
affectSumsControl <- data.frame(rbind(cbind(control$pasum, "positive"), cbind(control$nasum, "negative")))
names(affectSumsControl) <- c("Activation", "Valence")
affectSumsControl$Activation <- round(as.numeric(as.character(affectSumsControl$Activation)),0)

plotdat <- ddply(affectSumsControl, c("Activation", "Valence"), summarise, freq=length(Activation), .drop = FALSE)
dat.control.affectsum <- plotdat

tikz(file = paste0("affect_sums_control", ".tex"), width = 2.9, height = 2.25)

plot <- ggplot(plotdat, aes(x=Activation, y = freq, fill = Valence)) +
    geom_bar(stat="identity", position="dodge") +
    xlab("Summed activation") +
    ylab("Frequency") +
    theme_classic() +
    theme(
        axis.text.x = element_text(size = rel(0.9)),
        axis.text.y = element_text(size = rel(0.9)),
        axis.title = element_text(size = rel(0.9)),
        legend.title = element_text(size = rel(0.9)),
        legend.text = element_text(size = rel(0.9)),
        legend.key.size = unit(0.4, "cm"),
        legend.position = "bottom",
        legend.direction = "horizontal",
        legend.justification = "center",
        legend.margin = unit(0.1, "cm"),
        legend.background = element_rect(colour = "black", size = 0.5)
    ) +
    scale_fill_custom("Valence", labels = c("negative", "positive"),  guide = guide_legend(title.position = "left")) +
    geom_vline(xintercept=mean(affectSumsControl[affectSumsControl$Valence=="positive",]$Activation), color="darkgreen", linetype = "longdash") +
    geom_vline(xintercept=mean(affectSumsControl[affectSumsControl$Valence=="negative",]$Activation), color="darkred", linetype = "longdash")

print(plot)
dev.off()
print(plot)

mean(affectSumsControl[affectSumsControl$Valence=="positive",]$Activation)
mean(affectSumsControl[affectSumsControl$Valence=="negative",]$Activation)

observations <- sum(dat.control.affectsum$freq)/2
dat.control.affectsum$fraction <- dat.control.affectsum$freq / observations
dat.control.affectsum$type <- "control"


# Depressed
affectSumsDepressed <- data.frame(rbind(cbind(depressed$pasum, "positive"), cbind(depressed$nasum, "negative")))
names(affectSumsDepressed) <- c("Activation", "Valence")
affectSumsDepressed$Activation <- round(as.numeric(as.character(affectSumsDepressed$Activation)),0)

plotdat <- ddply(affectSumsDepressed, c("Activation", "Valence"), summarise, freq=length(Activation), .drop = FALSE)
dat.depressed.affectsum <- plotdat


tikz(file = paste0("affect_sums_depressed", ".tex"), width = 2.9, height = 2.25)

plot <- ggplot(plotdat, aes(x=Activation, y = freq, fill = Valence)) +
    geom_bar(stat="identity", position="dodge") +
    xlab("Summed activation") +
    ylab("Frequency") +
    theme_classic() +
    theme(
        axis.text.x = element_text(size = rel(0.9)),
        axis.text.y = element_text(size = rel(0.9)),
        axis.title = element_text(size = rel(0.9)),
        legend.title = element_text(size = rel(0.9)),
        legend.text = element_text(size = rel(0.9)),
        legend.key.size = unit(0.4, "cm"),
        legend.position = "bottom",
        legend.direction = "horizontal",
        legend.justification = "center",
        legend.margin = unit(0.1, "cm"),
        legend.background = element_rect(colour = "black", size = 0.5)
    ) +
    scale_fill_custom("Valence", labels = c("negative", "positive"),  guide = guide_legend(title.position = "left")) +
    geom_vline(xintercept=mean(affectSumsDepressed[affectSumsDepressed$Valence=="positive",]$Activation), color="darkgreen", linetype = "longdash") +
    geom_vline(xintercept=mean(affectSumsDepressed[affectSumsDepressed$Valence=="negative",]$Activation), color="darkred", linetype = "longdash")

print(plot)
dev.off()
print(plot)

mean(affectSumsDepressed[affectSumsDepressed$Valence=="positive",]$Activation)
mean(affectSumsDepressed[affectSumsDepressed$Valence=="negative",]$Activation)

t.test(depressed$pasum,depressed$nasum)

observations <- sum(dat.depressed.affectsum$freq)/2
dat.depressed.affectsum$fraction <- dat.depressed.affectsum$freq / observations
dat.depressed.affectsum$type <- "depressed"



####
#### PLot the same thing, but separated by affect instead of by model
####

#### Mean activation
affectmean <- rbind(dat.control.affectmean, dat.depressed.affectmean)
affectmean <- rbind(affectmean, cbind(expand.grid(Activation=c(-0.3,-0.2,-0.1,0,0.1,0.2,0.3,0.4), Valence=c("positive", "negative"), freq = 0, fraction=0, type = c("control", "depressed"))))
pamean <- affectmean[affectmean$Valence=="positive",]
namean <- affectmean[affectmean$Valence=="negative",]

# PAMEAN
tikz(file = paste0("affect_mean_positive", ".tex"), width = 2.9, height = 2.25)

plot <- ggplot(pamean, aes(x=Activation, y = fraction, fill = type)) +
    geom_bar(stat="identity", position="dodge") +
    xlab("Mean activation") +
    ylab("Frequency") +
    theme_classic() +
    theme(
        axis.text.x = element_text(size = rel(0.9)),
        axis.text.y = element_text(size = rel(0.9)),
        axis.title = element_text(size = rel(0.9)),
        legend.title = element_text(size = rel(0.9)),
        legend.text = element_text(size = rel(0.9)),
        legend.key.size = unit(0.4, "cm"),
        legend.position = "bottom",
        legend.direction = "horizontal",
        legend.justification = "center",
        legend.margin = unit(0.1, "cm"),
        legend.background = element_rect(colour = "black", size = 0.5)
    ) +
    scale_fill_custom("Model", labels = c("Control", "Depressed"),  guide = guide_legend(title.position = "left"))  +
    geom_vline(xintercept=mean(affectMeansControl[affectMeansControl$Valence=="positive",]$Activation), color="orange3", linetype = "longdash", size = 1.25) +
    geom_vline(xintercept=mean(affectMeansDepressed[affectMeansDepressed$Valence=="positive",]$Activation), color="darkblue", linetype = "longdash", size = 1.25)

print(plot)
dev.off()
print(plot)


# NAMEAN
tikz(file = paste0("affect_mean_negative", ".tex"), width = 2.9, height = 2.25)

plot <- ggplot(namean, aes(x=Activation, y = fraction, fill = type)) +
    geom_bar(stat="identity", position="dodge") +
    xlab("Mean activation") +
    ylab("Frequency") +
    theme_classic() +
    theme(
        axis.text.x = element_text(size = rel(0.9)),
        axis.text.y = element_text(size = rel(0.9)),
        axis.title = element_text(size = rel(0.9)),
        legend.title = element_text(size = rel(0.9)),
        legend.text = element_text(size = rel(0.9)),
        legend.key.size = unit(0.4, "cm"),
        legend.position = "bottom",
        legend.direction = "horizontal",
        legend.justification = "center",
        legend.margin = unit(0.1, "cm"),
        legend.background = element_rect(colour = "black", size = 0.5)
    ) +
    scale_fill_custom("Model", labels = c("Control", "Depressed"),  guide = guide_legend(title.position = "left"))  +
    geom_vline(xintercept=mean(affectMeansControl[affectMeansControl$Valence=="negative",]$Activation), color="orange3", linetype = "longdash", size = 1.25) +
    geom_vline(xintercept=mean(affectMeansDepressed[affectMeansDepressed$Valence=="negative",]$Activation), color="darkblue", linetype = "longdash", size = 1.25)

print(plot)
dev.off()
print(plot)



#### Summed activation
affectsum <- rbind(dat.control.affectsum, dat.depressed.affectsum)
affectsum <- rbind(affectsum, cbind(expand.grid(Activation=seq(-6,12,1), Valence=c("positive", "negative"), freq = 0, fraction=0, type = c("control", "depressed"))))
pasum <- affectsum[affectsum$Valence=="positive",]
nasum <- affectsum[affectsum$Valence=="negative",]

# PASUM
tikz(file = paste0("affect_sum_positive", ".tex"), width = 2.9, height = 2.25)

plot <- ggplot(pasum, aes(x=Activation, y = fraction, fill = type)) +
    geom_bar(stat="identity", position="dodge") +
    xlab("Summed activation") +
    ylab("Frequency") +
    theme_classic() +
    theme(
        axis.text.x = element_text(size = rel(0.9)),
        axis.text.y = element_text(size = rel(0.9)),
        axis.title = element_text(size = rel(0.9)),
        legend.title = element_text(size = rel(0.9)),
        legend.text = element_text(size = rel(0.9)),
        legend.key.size = unit(0.4, "cm"),
        legend.position = "bottom",
        legend.direction = "horizontal",
        legend.justification = "center",
        legend.margin = unit(0.1, "cm"),
        legend.background = element_rect(colour = "black", size = 0.5)
    ) +
    scale_fill_custom("Model", labels = c("Control", "Depressed"),  guide = guide_legend(title.position = "left"))  +
    geom_vline(xintercept=mean(affectSumsControl[affectSumsControl$Valence=="positive",]$Activation), color="orange3", linetype = "longdash", size = 1.25) +
    geom_vline(xintercept=mean(affectSumsDepressed[affectSumsDepressed$Valence=="positive",]$Activation), color="darkblue", linetype = "longdash", size = 1.25)

print(plot)
dev.off()
print(plot)

t.test(depressed$pasum, control$pasum)

# NASUM
tikz(file = paste0("affect_sums_negative", ".tex"), width = 2.9, height = 2.25)

plot <- ggplot(nasum, aes(x=Activation, y = fraction, fill = type)) +
    geom_bar(stat="identity", position="dodge") +
    xlab("Summed activation") +
    ylab("Frequency") +
    theme_classic() +
    theme(
        axis.text.x = element_text(size = rel(0.9)),
        axis.text.y = element_text(size = rel(0.9)),
        axis.title = element_text(size = rel(0.9)),
        legend.title = element_text(size = rel(0.9)),
        legend.text = element_text(size = rel(0.9)),
        legend.key.size = unit(0.4, "cm"),
        legend.position = "bottom",
        legend.direction = "horizontal",
        legend.justification = "center",
        legend.margin = unit(0.1, "cm"),
        legend.background = element_rect(colour = "black", size = 0.5)
    ) +
    scale_fill_custom("Model", labels = c("Control", "Depressed"),  guide = guide_legend(title.position = "left"))  +
    geom_vline(xintercept=mean(affectSumsControl[affectSumsControl$Valence=="negative",]$Activation), color="orange3", linetype = "longdash", size = 1.25) +
    geom_vline(xintercept=mean(affectSumsDepressed[affectSumsDepressed$Valence=="negative",]$Activation), color="darkblue", linetype = "longdash", size = 1.25)

print(plot)
dev.off()
print(plot)

t.test(depressed$nasum, control$nasum)


